﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.IdentityModel.Tokens;
using System.IdentityModel.Tokens.Jwt;
using SimpleFileServer.Dtos;
using SimpleFileServer.Models;
using System.Security.Claims;
using System.Text;

namespace SimpleFileServer.Controllers
{
    [ApiController]
    [Route("[controller]")]
    public class AuthController : ControllerBase
    {
        private readonly IConfiguration _configuration;

        public AuthController(IConfiguration configuration)
        {
            _configuration = configuration;
        }

        [HttpPost]
        [Route("Login")]
        public async Task<ActionResult> Login([FromBody] LoginDto login)
        {
            if (ModelState.IsValid)
            {
                var user = UserStore.Users.FirstOrDefault(u => u.Username == login.Username
                    && u.Password == login.Password);

                if (user is null)
                    return Unauthorized("Invalid credentials");

                var token = IssueToken(user);

                return Ok(token);

            }

            return BadRequest("Invalid Request Body");
        }

        private string IssueToken(ServiceUser user)
        {
            var securityKey = new SymmetricSecurityKey(Encoding.UTF8.GetBytes(_configuration["Jwt:Key"]));
            var credentials = new SigningCredentials(securityKey, SecurityAlgorithms.HmacSha256);
            var claims = new List<Claim>
            {
                new(ClaimTypes.NameIdentifier, user.Username),
                new(JwtRegisteredClaimNames.Sub, user.Id.ToString()),
            };
            user.Roles.ForEach(role => claims.Add(new Claim(ClaimTypes.Role, role.Name)));
            var token = new JwtSecurityToken(
                issuer: _configuration["Jwt:Issuer"],
                audience: _configuration["Jwt:Audience"],
                claims: claims,
                expires: DateTime.Now.AddHours(12),
                signingCredentials: credentials);
            return new JwtSecurityTokenHandler().WriteToken(token);
        }
    }
}
